proc sql noprint;
	create table debtratio as
	select * from mydata.debtratio 
	where symbol in (select symbol from output.relevantsymbols);
quit;

proc sort data=debtratio nodupkey;
	by symbol debt_ratio_08 debt_ratio_09 debt_ratio_10 debt_ratio_11 debt_ratio_12 debt_ratio_13;
run;

data debtratio;
	set debtratio;
	meandebtratio=mean(of debt_ratio_08-debt_ratio_13);
run;

proc sort data=debtratio;
	by meandebtratio;
run;

data debtratio;
	set debtratio;
	if _n_<=25 then debtratio_seg=1;
	else if _n_<=50 then debtratio_seg=2;
	else if _n_<=75 then debtratio_seg=3;
	else debtratio_seg=4;
run;

proc sort data=debtratio;
	by symbol;
run;


%macro NewRelevantData();
	%let ilag=1;
	%do %until (&ilag.>1);
	
		%put &ilag.;

		proc sort data=output.Relevantdata_nd5_tl&ilag.;
			by symbol;
		run;

		data output.Relevantdata_nd5_tl&ilag.;
			merge output.Relevantdata_nd5_tl&ilag. debtratio (keep=symbol debtratio_seg);
			by symbol;
		run;

		proc sort data=output.Relevantdata_nd5_tl&ilag.;
			by date symbol;
		run;

		%let ilag=%eval(&ilag.+1);
	%end;
%mend;

%NewRelevantData();	

%macro VarOrder();

	%let datanames=high low open price h_gk log_returns volume log_volume log_volume_linear_trend log_volume_linear_residual log_volume_expected log_volume_unexpected;
	%let lagdatanames=;

	%let lag=1;
	%do %until (&lag.>1);

	%let ilag=1;
	%do %until (&ilag.>5);

		%let idata=1;
		%do %until (%scan(&datanames.,&idata.,' ')=);

			%let dataname=%scan(&datanames.,&idata.,' ');
			%let lagdatanames=&lagdatanames. &dataname._tl&ilag.;

			%let idata=%eval(&idata.+1);
		%end;

		%let ilag=%eval(&ilag.+1);
	%end;

	data output.relevantdata_nd&negdis._tl&lag.;
		retain date symbol indicnews BL_neg_prop BL_agreeindex MPQA_neg_prop MPQA_agreeindex MPQA_strongneg_prop MPQA_strongagreeindex LM_neg_prop LM_agreeindex
			&datanames. &lagdatanames. GICS_sector sp500_log_returns_tl1 vix_close_tl1 debtratio_seg BL_pos_prop MPQA_pos_prop MPQA_strongpos_prop LM_pos_prop ;
		set output.relevantdata_nd&negdis._tl&lag.;
	run;

	PROC EXPORT DATA=output.relevantdata_nd5_tl&lag.    
		OUTFILE= "&outpath.\relevantdata_nd&negdis._tl&lag..txt"    
		DBMS=dlm REPLACE;    
		DELIMITER=';';
	RUN;

	%let lag=%eval(&lag.+1);
	%end;

%mend;

%VarOrder();
