/*	Read in Companies.csv.	*/
data MYDATA.Companies;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&datapath.\Companies.csv"
	delimiter = ';' MISSOVER DSD lrecl=32767 firstobs=2 ;
		informat TYPE $10. ;
		informat DSCD $10.;
		informat MNEM $100. ;
		informat ISIN $100. ;
		informat NAME $100. ;
		informat EXNAME $100. ;
		informat WC08003 $100. ;
		informat T1C $100. ;
		informat WC05601 $100. ;
		format TYPE $10. ;
		format DSCD $10.;
		format MNEM $100. ;
		format ISIN $100. ;
		format NAME $100. ;
		format EXNAME $100. ;
		format WC08003 $100. ;
		format T1C $100. ;
		format WC05601 $100. ;
		input	TYPE $
				DSCD $
				MNEM $
				ISIN $
				NAME $
				EXNAME $
				WC08003 $
				T1C $
				WC05601 $;
		rename	WC05601=symbol;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
run;


/*	Read in Constituents.csv.	*/
%macro Read_Constituents();
data MYDATA.Constituents    ;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&datapath.\Constituents.csv"
	delimiter = ';' MISSOVER DSD lrecl=32767 firstobs=2 ;
	informat monthyear $5.;
	format monthyear $5.;
	%let i=1;
	%do %until (&i>502);
		informat DSCD&i. $10.;
		format DSCD&i. $10.;
		%let i=%eval(&i+1);
	%end;
	input monthyear DSCD1-DSCD502;
	month=scan(monthyear,1,"-");
	year=scan(monthyear,2,"-");
	drop monthyear;
run;
%mend;

%Read_Constituents();
	


/*	Read in High.csv and store to SAS data High.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_High.sas";
%Read_High();


/*	Read in Low.csv and store to SAS data Low.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Low.sas";
%Read_Low();


/*	Read in Open.csv and store to SAS data Open.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Open.sas";
%Read_Open();


/*	Read in Price.csv and store to SAS data Price.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Price.sas";
%Read_Price();


/*	Read in H_gk.csv and store to SAS data H_gk.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_H_gk.sas";
%Read_H_gk();


/*	Read in Log_returns.csv and store to SAS data Log_Return.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Returns.sas";
%Read_Log_Returns();


/*	Read in Volume.csv and store to SAS data Volume.  First, in a text editor, replace all "NA" with "", "," with ".", and "-Inf" with "-999999",
	and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Volume.sas";
%Read_Volume();


/*	Read in Log_Volume.csv and store to SAS data Log_Volume.  
	First, in a text editor, replace all "NA" with "", "," with ".", and "-Inf" with "-999999", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Volume.sas";
%Read_Log_Volume();
/*	Note that there is value of -999999, representing -Inf.	*/


/*	Read in Log_Volume_Detrend120_ARMA120_Linear-Trend.csv and store to SAS data Log_Volume_Linear_Trend.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Volume_Linear_Trend.sas";
%Read_Log_Volume_Linear_Trend();
 

/*	Read in Log_Volume_Detrend120_ARMA120_Linear-Trend-Residual.csv and store to SAS data Log_Volume_Linear_Residual.  
	First, in a text editor, replace all "NA" with "", "," with ".", and "-Inf" with "-999999", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Volume_Linear_Residual.sas";
%Read_Log_Volume_Linear_Residual();
/*	Note that there is value of -999999, representing -Inf.	*/


/*	Read in Log_Volume_Detrend120_ARMA120_Expected-Volume.csv and store to SAS data Log_Volume_Expected.  First, in a text editor, replace all "NA" with "", and "," with ".", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Volume_Expected.sas";
%Read_Log_Volume_Expected();


/*	Read in Log_Volume_Detrend120_ARMA120_Unexpected-Volume.csv and store to SAS data Log_Volume_Unexpected.  
	First, in a text editor, replace all "NA" with "", "," with ".", and "-Inf" with "-999999", and then run the following SAS code.	*/
%include "&macropath.\ReadSP500Data_Log_Volume_Unexpected.sas";
%Read_Log_Volume_Unexpected();
/*	Note that there is value of -999999, representing -Inf.	*/

 
