data OUTPUT.SYMBOL_ARTICLE_RELATIONS;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&outpath.\symbol_article_relations.txt"
	delimiter='09'x MISSOVER DSD lrecl=32767 ;
		informat symbol $100. ;
		informat author $100. ;
		informat linkfile best32. ;
		informat link best32. ;
		informat temp $1. ;
		format symbol $100. ;
		format author $100. ;
		format linkfile best32. ;
		format link best32. ;
		format temp $1. ;
		input	symbol $
				author $
				linkfile
				link
				temp $;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
run;

data output.Articles_date    ;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&outpath.\articles_date.txt" delimiter='09'x MISSOVER DSD lrecl=32767 ;
		informat order best32. ;
		informat author $100. ;
		informat linkfile best32. ;
		informat link best32. ;
		informat date mmddyy10.;
		informat flag best32.;
		format order best32. ;
		format author $100. ;
		format linkfile best32. ;
		format link best32. ;
		format date mmddyy10.;
		format flag best32.;
		input	order 
				author $
				linkfile
				link
				date
				flag;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
run;


data output.symbol_article_relations;
	set output.symbol_article_relations;
	symbol=cats(symbol);
	drop temp;
run;


/*	Some symbols appear in the "Companies" data set more than once, remove these symbols, the S&P500 data for their corresponding DSCD
	and their corresponding articles from further analysis.	*/
data Companies;
	set mydata.Companies;
	symbol=cats(lowcase(symbol));
run;

proc freq data=Companies noprint;
	table symbol /out=a0;
run;
data a0;
	set a0;
	if count>1;
run;
proc sql noprint;
	create table mydata.Companies as
	select * from Companies
	where symbol not in (select symbol from a0);
quit;

/*	Find the DSCD and the corresponding symbol where the DSCD appears in the S&P 500 data "dataname",	
	and the corresponding symbol appears in output.symbol_article_relations with the corresponding article having flag 1 in output.articles_date.	*/
%macro FindDSCDSymbol(dataname);
proc contents data=mydata.&dataname. out=contents noprint;
run;

data &dataname._DSCD;
	set contents;
	NAME=cats(NAME);
	if find(NAME,"X")>0;
	DSCD=substr(NAME,2,7);
	keep DSCD;
run;

proc sql noprint;
	create table tempsymbol as 
	select unique(symbol) from output.symbol_article_relations 
	where cats(author,linkfile,link) in (select cats(author,linkfile,link) from output.articles_date where flag=1);
quit;

proc sql noprint;
	create table mydata.&dataname._DS as
	select a.DSCD, b.symbol from &dataname._DSCD a, mydata.Companies b
	where a.DSCD=b.DSCD and b.symbol in (select symbol from tempsymbol);
quit;

%mend;	

%FindDSCDSymbol(High);
%FindDSCDSymbol(Low);
%FindDSCDSymbol(Open);
%FindDSCDSymbol(Price);
%FindDSCDSymbol(H_gk);
%FindDSCDSymbol(Log_Returns);
%FindDSCDSymbol(Volume);
%FindDSCDSymbol(Log_Volume);
%FindDSCDSymbol(Log_Volume_Linear_Trend);
%FindDSCDSymbol(Log_Volume_Linear_Residual);
%FindDSCDSymbol(Log_Volume_Expected);
%FindDSCDSymbol(Log_Volume_Unexpected);
