/*	Construct a data set with the average sentiment scores of articles posted on or after the past &lag.'th trading day and before the focus trading day.	*/
%let negdis=5;	/* The allowed distance for negation words.	*/
%let lag=1;

/*	output.articles_date: order, author, linkfile, link and date for all existing articles.	*/
data output.articles_date;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&outpath.\articles_date.txt" delimiter='09'x MISSOVER DSD lrecl=32767 ;
	informat order best32.;
	informat author $100.;
	informat linkfile best32.;
	informat link best32.;
	informat date mmddyy10.;
	informat flag best32.;
	format order best32.;
	format author $100.;
	format linkfile best32.;
	format link best32.;
	format date yymmdd10.;
	format flag best32.;
	input order author linkfile link date flag;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
run;

/*	output.articles_sentiment_negdis&negdis.: order, length and counts of sentiment words for all articles with positive length.	*/
data output.articles_sentiment_negdis&negdis.;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&outpath.\articles_sentiment_negdis&negdis..txt" delimiter='09'x MISSOVER DSD lrecl=32767 ;
	informat order best32. ;
	informat length best32. ;
	informat BL_pos best32. ;
	informat BL_neg best32. ;
	informat MPQA_weakpos best32. ;
	informat MPQA_strongpos best32. ;
	informat MPQA_weakneutral best32. ;
	informat MPQA_strongneutral best32. ;
	informat MPQA_weakneg best32. ;
	informat MPQA_strongneg best32. ;
	informat MPQA_weakboth best32. ;
	informat MPQA_strongboth best32. ;
	format order best32. ;
	format length best32. ;
	format BL_pos best32. ;
	format BL_neg best32. ;
	format MPQA_weakpos best32. ;
	format MPQA_strongpos best32. ;
	format MPQA_weakneutral best32. ;
	format MPQA_strongneutral best32. ;
	format MPQA_weakneg best32. ;
	format MPQA_strongneg best32. ;
	format MPQA_weakboth best32. ;
	format MPQA_strongboth best32. ;
	input	order
			length
			BL_pos
			BL_neg
			MPQA_weakpos
			MPQA_strongpos
			MPQA_weakneutral
			MPQA_strongneutral
			MPQA_weakneg
			MPQA_strongneg
			MPQA_weakboth
			MPQA_strongboth;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
	if length>0;	/* Only keep the articles with positive length. */
run;

data articles_sentiment_negdis&negdis._LM;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile "&outpath.\articles_sentiment_negdis&negdis._LM.txt" delimiter='09'x MISSOVER DSD lrecl=32767 ;
	informat order best32. ;
	informat length best32. ;
	informat LM_negative best32. ;
	informat LM_positive best32. ;
	informat LM_uncertainty best32. ;
	informat LM_litigious best32. ;
	informat LM_modalstrong best32. ;
	informat LM_modalweak best32. ;
	format order best32. ;
	format length best32. ;
	format LM_negative best32. ;
	format LM_positive best32. ;
	format LM_uncertainty best32. ;
	format LM_litigious best32. ;
	format LM_modalstrong best32. ;
	format LM_modalweak best32. ;
	input	order
			length
			LM_negative
			LM_positive
			LM_uncertainty
			LM_litigious
			LM_modalstrong
			LM_modalweak;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
	if length>0;	/* Only keep the articles with positive length. */
run;

data output.articles_sentiment_negdis&negdis.;
	merge output.articles_sentiment_negdis&negdis. articles_sentiment_negdis&negdis._LM (drop=length);
	by order;
run;

/*	The dates for which there are articles with counts of sentiment words.	*/
proc sql noprint;
	create table relevant_articledates as
	select unique(date) from output.articles_date
	where order in (select order from output.articles_sentiment_negdis&negdis.);
quit;

proc sort data=relevant_articledates;
	by date;
run;

proc univariate data=relevant_articledates;
	histogram date;
run;

/*	2009-04-20 and 2009-10-09 are two outlier dates that correspond to 5 articles.  Delete these articles.  The rest of the dates start from 2009-10-20.	*/
data temp;
	set output.articles_date;
	if date<mdy(10,20,2009);
run;
data output.articles_date;
	set output.articles_date;
	if date>=mdy(10,20,2009);
run;


/*	merge symbols, article dates and article sentiment scores where the symbols are in the "high_ds" data set (we have the trading information for the symbols).	*/
proc sql noprint;
	create table output.sym_arti_sent_negdis&negdis. as
	select b.date, a.symbol, b.order, c.length, c.BL_pos, c.BL_neg, 
		c.MPQA_weakpos, c.MPQA_strongpos, c.MPQA_weakneg, c.MPQA_strongneg, c.MPQA_weakneutral, c.MPQA_strongneutral, c.MPQA_weakboth, c.MPQA_strongboth,
		c.LM_negative, c.LM_positive, c.LM_uncertainty, c.LM_litigious, c.LM_modalstrong, c.LM_modalweak
	from output.Symbol_article_relations a, output.articles_date b, output.Articles_sentiment_negdis&negdis. c
	where cats(a.author,"-",a.linkfile,"-",a.link)=cats(b.author,"-",b.linkfile,"-",b.link) and b.order=c.order 
	and a.symbol in (select symbol from mydata.High_DS);
quit;

proc sort data=output.sym_arti_sent_negdis&negdis.;
	by date symbol;
run;


/*	Get trading dates with nonmissing volume.	*/
data tradingdates;
	set mydata.volume;
	if X902172 ne .;
	keep date;
run;

proc sort data=tradingdates;
	by date;
run;

data tradingdates;
	set tradingdates;
	index=_n_;
run;

/*	Get how the natural dates correspond to the past trading days and the future trading days.	*/
/***	Create a data set with natural dates from 2008-1-1 to 2014-11-3, the range of trading dates in the trading data.	***/
data temp;
	ndays=mdy(11,3,2014)-mdy(1,1,2008);
run;
proc sql noprint;
	select ndays into :ndays from temp;
quit;
%macro CreateNaturalDates();
	data naturaldates;
		retain date;
		date=mdy(1,1,2008);
		output;
		%let i=1;
		%do %until (%eval(&i.>&ndays.));
			date=date+1;
			output;
			%let i=%eval(&i+1);
		%end;
		format date YYMMDD10.;
	run;
%mend;

%CreateNaturalDates();


/***	Get the correspondence of the natural dates to the future trading days.
	Articles published on the focal natural date can be used for trading dates from tdate_lag1 to tdate_lag&lag..	*/
%macro DateMapping();

	/***** mapping from natural days to the future trading days 	*****/

	/*******	mapping from natural days to the index of trading days.	*******/
	proc sql noprint;
		create table datemapping1 as
		select date, 0 as index from naturaldates
		where date not in (select date from tradingdates);
	quit;

	proc sql noprint;
		create table datemapping2 as
		select * from tradingdates
		where date in (select date from naturaldates);
	quit;

	data datemapping;
		set datemapping1 datemapping2;
	run;

	proc sort data=datemapping;
		by date;
	run;	

	data datemapping;
		set datemapping;
		retain newindex;
		if index>0 then newindex=index;
		drop index;
		if newindex ne .;
		rename newindex=index;
	run;

	/******* mapping from natural days to the future trading days (tdate_lag&ilag.)	*******/
	%let ilag=1;
	%do %until (&ilag.>&lag.);

		data temp1;
			set datemapping;
			index=index+&ilag.;
		run;

		data temp2;
			merge temp1 (in=data1) tradingdates (rename=(date=tdate_lag&ilag.));
			by index;
			if data1;
			drop index;
		run;	

		%if &ilag.=1 %then %do;
			data output.datemapping_tl&lag.;
				set temp2;
			run;
		%end;
		%else %do;
			data output.datemapping_tl&lag.;
				merge output.datemapping_tl&lag. temp2;
				by date;
			run;
		%end;

		%let ilag=%eval(&ilag.+1);
	%end;
%mend;

%DateMapping();






/*	For each trading date and each symbol, output.sym_arti_sent_alllags_nd&negdis._tl&lag. contains counts of sentiment words for all relevant articles
	(articles in the lagged time window). 	*/
%macro SentDataAllLags();
	
	%let ilag=1;
	%do %until (%eval(&ilag.>&lag.));
		data temp;
			merge output.sym_arti_sent_negdis&negdis. (in=data1) output.datemapping_tl&lag. (keep=date tdate_lag&ilag.);
			by date;
			if data1;
			drop date;
			rename tdate_lag&ilag.=date;
		run;
		data temp;
			retain date;
			set temp;
		run;

		%if &ilag.=1 %then %do;
			data output.sym_arti_sent_alllags_nd&negdis._tl&lag.;
				set temp;
			run;
		%end;
		%else %do;
			data output.sym_arti_sent_alllags_nd&negdis._tl&lag.;
				set output.sym_arti_sent_alllags_nd&negdis._tl&lag. temp;
			run;
		%end;
		%let ilag=%eval(&ilag.+1);
	%end;

	proc sort data=output.sym_arti_sent_alllags_nd&negdis._tl&lag.;
		by date symbol;
	run;
%mend;

%SentDataAllLags();


/*	Only keep the records with complete observations in relevant time window, i.e., with dates on or after 2009-10-27 (5 trading days after 2009-10-20, 
	the first date for which there are articles with counts of sentiment words available), and on or before 2014-10-14 
	(2014-10-13 is the last date for which there are articles with counts of sentiment words available)	*/
data output.sym_arti_sent_alllags_nd&negdis._tl&lag.;
	set output.sym_arti_sent_alllags_nd&negdis._tl&lag.;
	if date>=mdy(10,21,2009) and date<=mdy(10,14,2014); /* lag=1 */
	*if date>=mdy(10,22,2009) and date<=mdy(10,14,2014); /* lag=2 */
	*if date>=mdy(10,23,2009) and date<=mdy(10,14,2014); /* lag=3 */
	*if date>=mdy(10,26,2009) and date<=mdy(10,14,2014); /* lag=4 */
	**if date>=mdy(10,27,2009) and date<=mdy(10,14,2014); /* lag=5	*/
run;


/*	Compute the independent variables for each date and each symbol.	*/
/***	The average value of the following variables:
		BL_pos_prop: BL_pos/length
		BL_neg_prop: BL_neg/length
		BL_pos_relprop: BL_pos/(BL_pos+BL_neg)
		BL_pn_ratio: BL_pos/BL_neg
		MPQA_weakpos_prop: MPQA_weakpos/length
		MPQA_strongpos_prop: MPQA_strongpos/length
		MPQA_weakneg_prop: MPQA_weakneg/length
		MPQA_strongneg_prop: MPQA_strongneg/length
		MPQA_weakneutral_prop: MPQA_weakneutral/length
		MPQA_strongneutral_prop: MPQA_strongneutral_prop/length
		MPQA_pos_prop: (MPQA_weakpos+MPQA_strongpos)/length
		MPQA_neg_prop: (MPQA_weakneg+MPQA_strongneg)/length
		MPQA_neutral_prop: (MPQA_weakneutral+MPQA_strongneutral)/length
		MPQA_pos_relprop: (MPQA_weakpos+MPQA_strongpos)/(MPQA_weakpos+MPQA_strongpos+MPQA_weakneg+MPQA_strongneg+MPQA_weakneutral+MPQA_strongneutral)
		MPQA_neg_relprop: (MPQA_weakneg+MPQA_strongneg)/(MPQA_weakpos+MPQA_strongpos+MPQA_weakneg+MPQA_strongneg+MPQA_weakneutral+MPQA_strongneutral)	
		MPQA_pn_ratio: (MPQA_weakpos+MPQA_strongpos)/(MPQA_weakneg+MPQA_strongneg) 
		LM_pos_prop: LM_positive/length
		LM_neg_prop: LM_negative/length
		LM_uncertainty_prop: LM_uncertainty/length
		LM_litigious_prop: LM_litigious/length
		LM_modalstrong_prop: LM_modalstrong/length
		LM_modalweak_prop: LM_modalweak/length
		LM_pos_relprop: LM_positive/(LM_positive+LM_negative)
		LM_pn_ratio: LM_positive/LM_negative	***/
%macro ComputeAveSentScore();
	proc sql noprint;
		create table output.SentScore_nd&negdis._tl&lag. as
		select date, symbol,
			count(*) as nreview, 
			mean(length) as avelen, 
			mean(BL_pos/length) as BL_pos_prop, 
			mean(BL_neg/length) as BL_neg_prop, 
			mean(log((1+BL_pos)/(1+BL_neg))) as BL_agreeindex,
			mean((MPQA_weakpos+MPQA_strongpos)/length) as MPQA_pos_prop, 
			mean((MPQA_weakneg+MPQA_strongneg)/length) as MPQA_neg_prop,
			mean(log((1+MPQA_weakpos+MPQA_strongpos)/(1+MPQA_weakneg+MPQA_strongneg))) as MPQA_agreeindex,
			mean(MPQA_strongpos/length) as MPQA_strongpos_prop, 
			mean(MPQA_strongneg/length) as MPQA_strongneg_prop,
			mean(log((1+MPQA_strongpos)/(1+MPQA_strongneg))) as MPQA_strongagreeindex,
			mean(LM_positive/length) as LM_pos_prop,
			mean(LM_negative/length) as LM_neg_prop,
			mean(log((1+LM_positive)/(1+LM_negative))) as LM_agreeindex
		from output.sym_arti_sent_alllags_nd&negdis._tl&lag.
		group by date, symbol
		order by date, symbol;
	quit;
%mend;

%ComputeAveSentScore();

data output.Sentscore_nd&negdis._tl&lag.;
	set output.Sentscore_nd&negdis._tl&lag.;
	if date>=mdy(10,21,2009) and date<=mdy(10,14,2014); /* lag=1 */
	*if date>=mdy(10,22,2009) and date<=mdy(10,14,2014); /* lag=2 */
	*if date>=mdy(10,23,2009) and date<=mdy(10,14,2014); /* lag=3 */
	*if date>=mdy(10,26,2009) and date<=mdy(10,14,2014); /* lag=4 */
	*if date>=mdy(10,27,2009) and date<=mdy(10,14,2014); /* lag=5	*/
run;

