/*	Get trading dates (with nonmissing volume).	*/
data tradingdates;
	set mydata.volume;
	if X902172 ne .;
	keep date;
run;

proc sort data=tradingdates;
	by date;
run;

data tradingdates;
	set tradingdates;
	index=_n_;
run;


/*	Lagged dependent variables in S&P 500 data.	*/
%macro LagDependentVars();

	proc sql noprint;
		select unique(symbol) into :allsymbols separated by ' ' from output.SentScore_nd&negdis._tl1;
	quit;
	
	%let datanames=high low open price h_gk log_returns volume log_volume log_volume_linear_trend log_volume_linear_residual log_volume_expected log_volume_unexpected;

	%let isymbol=1;
	%do %until (%scan(&allsymbols.,&isymbol.,' ')=);

		%put &isymbol.;
		%let symbol=%scan(&allsymbols.,&isymbol.,' ');

		%let idata=1;
		%do %until (%scan(&datanames.,&idata.,' ')=);
			
			%let dataname=%scan(&datanames.,&idata,' ');
			
 			data &dataname.;
				set mydata.&dataname._new;
				keep date &symbol.;
				rename &symbol.=&dataname.;
			run;

			proc sort data=&dataname.;
				by date;
			run;

			%let ilag=1;
			%do %until (&ilag.>5);
				data temp;
					merge &dataname. tradingdates;
					by date;
					if index ne .;
					drop &dataname.;
				run;

				data temp;
					set temp;
					index=index-&ilag.;
					if index>0;
				run;

				data temp;
					merge temp (in=data1) tradingdates (rename=(date=lagdate));
					by index;
					if data1;
				run;

				data temp2;
					set &dataname.;
					rename date=lagdate;
				run;

				data temp;
					merge temp (in=data1) temp2;
					by lagdate;
					if data1;
				run;

				data temp;
					set temp;
					rename &dataname.=&dataname._tl&ilag.;
					keep date &dataname.;
				run;

				%if &ilag.=1 %then %do;
					data final_&dataname.;
						set temp;
					run;
				%end;
				%else %do;
					data final_&dataname.;
						merge final_&dataname. temp;
						by date;
					run;
				%end;

				%let ilag=%eval(&ilag.+1);
			%end;

			%if &idata=1 %then %do;
				data final_lagdepvars;
					set final_&dataname.;
				run;
			%end;
			%else %do;
				data final_lagdepvars;
					merge final_lagdepvars final_&dataname.;
					by date;
				run;
			%end;

			%let idata=%eval(&idata.+1);
		%end;

		data final_lagdepvars;
			set final_lagdepvars;
			length symbol $20.;
			symbol="&symbol.";
		run;

		%if &isymbol.=1 %then %do;
			data output.alldepvars_alllags;
				set final_lagdepvars;
			run;
		%end;
		%else %do;
			data output.alldepvars_alllags;
				set output.alldepvars_alllags final_lagdepvars;
			run;
		%end;
		%let isymbol=%eval(&isymbol.+1);
	%end;

	proc sort data=output.alldepvars_alllags;
		by date symbol;
	run;

	data output.alldepvars_alllags;
		set output.alldepvars_alllags;
		%let ilag=1;
		%do %until (&ilag.>1);
			if volume_tl&ilag.=. then do;
				high_tl&ilag.=.;
				low_tl&ilag.=.;
				open_tl&ilag.=.;
				price_tl&ilag.=.;
				log_returns_tl&ilag.=.;
			end;
			%let ilag=%eval(&ilag.+1);
		%end;
	run;

%mend;


%LagDependentVars();

/*	Dependent variables in S&P 500 data.	*/
%macro DependentVars();

	proc sql noprint;
		select unique(symbol) into :allsymbols separated by ' ' from output.SentScore_nd&negdis._tl1;
	quit;
	
	%let datanames=high low open price h_gk log_returns volume log_volume log_volume_linear_trend log_volume_linear_residual log_volume_expected log_volume_unexpected;

	%let isymbol=1;
	%do %until (%scan(&allsymbols.,&isymbol.,' ')=);

		%put &isymbol.;
		%let symbol=%scan(&allsymbols.,&isymbol.,' ');

		%let idata=1;
		%do %until (%scan(&datanames.,&idata.,' ')=);
			
			%let dataname=%scan(&datanames.,&idata,' ');
			
 			data &dataname.;
				set mydata.&dataname._new;
				keep date &symbol.;
				rename &symbol.=&dataname.;
			run;

			proc sort data=&dataname.;
				by date;
			run;

			%if &idata=1 %then %do;
				data final_depvars;
					set &dataname.;
				run;
			%end;
			%else %do;
				data final_depvars;
					merge final_depvars &dataname.;
					by date;
				run;
			%end;

			%let idata=%eval(&idata.+1);
		%end;

		data final_depvars;
			set final_depvars;
			length symbol $20.;
			symbol="&symbol.";
		run;

		%if &isymbol.=1 %then %do;
			data output.alldepvars;
				set final_depvars;
			run;
		%end;
		%else %do;
			data output.alldepvars;
				set output.alldepvars final_depvars;
			run;
		%end;
		%let isymbol=%eval(&isymbol.+1);
	%end;

	data output.alldepvars;
		set output.alldepvars;
		if volume=. then do;
			high=.;
			low=.;
			open=.;
			price=.;
			log_returns=.;
		end;
	run;

%mend;

%DependentVars();	
