/*	Get trading dates (with nonmissing volume) between 2009-10-20, the first date with articles, and 2014-10-14, the trading date after the last date with articles.	*/
data tradingdates;
	set mydata.volume;
	if date>=mdy(10,20,2009) and date<=mdy(10,14,2014);
	if X902172 ne .;
	keep date;
run;

proc sort data=tradingdates;
	by date;
run;

proc sort data=mydata.high_new;
	by date;
run;

data high;
	merge tradingdates (in=data1) mydata.high_new;
	by date;
	if data1;
run;

/*	Count the number of days for which the symbols have trading information or article information (according to lag 1).	*/
%macro CountDays();
	proc sql noprint;
		select unique(symbol) into :allsymbols separated by ' ' from output.SentScore_nd&negdis._tl1;
	quit;

	%let isymbol=1;
	%do %until (%scan(&allsymbols.,&isymbol.,' ')=);

		%put &isymbol.;

		%let symbol=%scan(&allsymbols.,&isymbol.,' ');

		/*	The number of trading days with trading information.	*/
		proc sql noprint;
			select count(*) into :ntradingdays from high
			where &symbol. ne .;
		quit;

		/*	The number of trading days having articles with sentiment counts.	*/
		proc sql noprint;
			select count(*) into :narticledays from output.Finaldata_nd5_tl1
			where symbol="&symbol." and indicnews=1;
		quit;

		data temp;
			length symbol $20.;
			symbol="&symbol.";
			ntradingdays=&ntradingdays.;
			narticledays=&narticledays.;
			output;
		run;

		%if &isymbol.=1 %then %do;
			data allndays;
				set temp;
			run;
		%end;
		%else %do;
			data allndays;
				set allndays temp;
			run;
		%end;
		%let isymbol=%eval(&isymbol.+1);
	%end;
%mend;

%CountDays();

data output.allndays;
	set allndays;
run;

data allndays2;
	set output.allndays;
	if ntradingdays=1255;/* the stocks that trade every day */
run;

proc sort data=allndays2;
	by descending narticledays;
run;

/*	GICS_sector for each symbol.	*/
data sector    ;
	%let _EFIERR_ = 0; /* set the ERROR detection macro variable */
	infile 'D:\research\Collaboration with Wolfgang Haerdle\20141113 SP500 Datastream Data\Constituents_October_2014.csv' delimiter = ';' MISSOVER DSD lrecl=32767 firstobs=2 ;
	informat symbol $20. ;
	informat name $100. ;
	informat GICS_sector $100. ;
	informat GICS_industry_group $100. ;
	informat GICS_industry $100. ;
	informat GICS_industry_sub $100. ;
	format symbol $20. ;
	format name $100. ;
	format GICS_sector $100. ;
	format GICS_industry_group $100. ;
	format GICS_industry $100. ;
	format GICS_industry_sub $100. ;
	input	symbol $
			name $
			GICS_sector $
			GICS_industry_group $
			GICS_industry $
			GICS_industry_sub $;
	if _ERROR_ then call symputx('_EFIERR_',1);  /* set ERROR detection macro variable */
	symbol=lowcase(symbol);
	keep symbol GICS_sector;
run;

proc freq data=sector;
	table GICS_sector;
run;

proc sql noprint;
	create table allndays3 as
	select * from allndays2 
	where symbol in (select symbol from sector);
quit;

data relevantsymbols;
	set allndays3;
	if _n_<=100;
run;

proc sql noprint;
	create table output.relevantsymbols as
	select a.*, b.GICS_sector
	from relevantsymbols a, sector b
	where a.symbol=b.symbol;
quit;

proc sort data=output.relevantsymbols;
	by descending narticledays;
run;


%macro RelevantData();

	proc sort data=output.controlvars;
		by date symbol;
	run;

	%let ilag=1;
	%do %until (&ilag.>1);
	
		%put &ilag.;

		proc sort data=output.Finaldata_nd5_tl&ilag.;
			by date symbol;
		run;

		data temp;
			merge output.Finaldata_nd5_tl&ilag. (in=data1) output.controlvars;
			by date symbol;
			if data1;
		run;

		proc sql noprint;
			create table output.relevantdata_nd5_tl&ilag. as
			select * from temp
			where symbol in (select symbol from output.relevantsymbols);
		quit;

		proc sort data=output.Relevantdata_nd5_tl&ilag.;
			by date symbol;
		run;

/*		PROC EXPORT DATA=output.relevantdata_nd5_tl&ilag.    
            OUTFILE= "&outpath.\relevantdata_nd&negdis._tl&ilag..txt"    
            DBMS=dlm REPLACE;    
			DELIMITER=';';
		RUN;*/

		%let ilag=%eval(&ilag.+1);
	%end;
%mend;

%RelevantData();	
