setwd("H:/Profile.V2/Documents/BS")
library(KernSmooth)
library(quantreg)
library(np)

# Functions

lprq3 = function(x, y, h, x0) {
 xx = x0
 fv = xx
 dv = xx
 for(i in 1:length(xx)) {
   z = x - xx[i]
   wx = dnorm(z/h)
   r = rq(y~z, weights=wx, tau=runif(1), ci=FALSE)
   fv[i] = r$coef[1]
   dv[i] = r$coef[2]
 }  
 list(xx = xx, fv = fv, dv = dv)
}

# Gaussian Kernel
k_gauss = function(u){
  x = ( 1 / (sqrt( 2*pi )) ) * exp( (-1/2)* (u^2) )
  return(x)
}

# Kh Version of Gaussian kernel
kh_gauss = function(u, h){
  return( (1/h) * k_gauss(u/h) )
}

# Function to compute Nadaraya Watson Weights W_hi
W_hi  = function(x, xi, h){
  n   = length(xi)
  if(length(x) == 1){
    out = kh_gauss((x - xi), h) / ((1/n) * sum( kh_gauss((x - xi), h) ) )
    return(out)
  }else{
    print("Error: Do not use this on vector")
  }
  
}

# Function to estimate NW
mhat_h  = function(x, xi, yi, h){
  n   = length(xi)
  if(length(x) == 1){
    W   = sapply(x, function(x) W_hi(x, xi, h))
    m   = (1/n) * sum(W*yi)
    return(m)
  }else{
    print("Error: Do not use this on vector")
  }
}

#### One Step M-Type Estimator
psi = function(u, c){
  if(abs(u) <= c) return(u);
  return(sign(u)*c)
}

psideriv = function(u, c){
  if(c     <= 0 & c - u <= 0) return(0);
  if(c - u >  0 & c + u <= 0) return(0);
  if(c     >  0 & c - u <= 0) return(0);
  return(1)
}

# Function to compute additional Term in M-Type Smoother at one Point
M_weight  = function(x, xi, resid_psi, resid_psid, h, c){
  n   = length(xi)
  if(length(x) == 1){
    nom = sum( kh_gauss((x - xi), h) * resid_psi )
    denom = sum( kh_gauss((x - xi), h) * resid_psid )
    return(nom/denom)
  }else{
    print("Error: Do not use this on vector")
  } 
}

# Function to estimate robust NW
mhatr_h  = function(x, xi, yi, h, c){
  # Compute Standard NW estimator vor all xi
  yhatsort_h    = sapply(xi, function(u) mhat_h(u, xi, yi, h))
  # Compute residuals
  rhatsort_h    = yi - yhatsort_h
  # Compute yhat for prespecified grid
  yhatsort_h    = sapply(x , function(u) mhat_h(u, xi, yi, h))
  # Use Huber Psi Function
  resid_psi     = sapply(rhatsort_h, function(u) psi(u, c))
  resid_psid    = sapply(rhatsort_h, function(u) psideriv(u, c))
  # Compute additional Term in M-Type Smoother for prespecified grid
  weights       = sapply(x , function(u) M_weight(u, xi, resid_psi, resid_psid, h, c))
  
  return(yhatsort_h + weights)
}


kernelq = function(u){dnorm(u,mean=0,sd=1)} 

###################
setwd("")
options(stringsAsFactors = FALSE)

attent_sim.df = read.csv2("AttentionSimulation.csv")
attent_sim.df = attent_sim.df[attent_sim.df$Attention == "Extremely High", ]



x = c(attent_sim.df$LM_Neg_Proportion)
y = c(attent_sim.df$LM_SimulatedVolatility)

plot(x, y)


minrange = max(min(attent_sim.df$LM_Neg_Proportion), min(attent_sim.df$LM_Pos_Proportion))
maxrange = min(max(attent_sim.df$LM_Neg_Proportion), max(attent_sim.df$LM_Pos_Proportion))
rangeposneg = c(minrange, maxrange)
rangeposneg
###################

n    = length(x)
B    = 500
c    = 1

gridn = 100  # number of points where to estimate

xsort   = sort(x) 
ysort   = y[order(x)]

plot(xsort, ysort)
h       = 0.012
g       = 0.03
hg      = 0.012
c       = 1
dpill(xsort, ysort)
bin           = bkde(xsort, gridsize = gridn, range.x = rangeposneg)$x
fxd           = bkde(xsort, gridsize = gridn,  range.x = rangeposneg)
bin
yhatsort_h    = mhatr_h(bin, xsort, ysort, h, c)
yhatsort_g    = mhatr_h(xsort, xsort, ysort, g, c)
plot(xsort, ysort)
lines(bin, yhatsort_h, col = "red")


fl    = vector(length= gridn, mode="numeric")
fll   = vector(length= gridn, mode="numeric")
flstar    = vector(length= gridn, mode="numeric")
fllstar   = vector(length= gridn, mode="numeric")


for (k in 1: gridn){
  fl[k]  = sum((kernelq((xsort - bin[k])/(hg))*
                  sapply(ysort, function(u) psideriv((u -  yhatsort_h[k]),c = c))))/
    sum(kernelq((xsort -  fxd$x[k])/(hg)))
  
  fll[k] = sum((kernelq((xsort - bin[k])/(hg))*
                  sapply(ysort, function(u) psi(((u - yhatsort_h[k])),c = c)^2)))/
    sum(kernelq((xsort -  bin[k])/(hg)))
  
} 

bandt  = (fxd$y)^(1/2)*abs(fl/sqrt(fll)) 


yhatsort_h    = mhatr_h(xsort, xsort, ysort, h, c)
yhatsort_g    = mhatr_h(xsort, xsort, ysort, g, c)

d = vector(length= B, mode="numeric") 
for(jj in 1:B){
  fitroberror = lprq3( xsort, (ysort - yhatsort_h), h = h, x0 =  xsort )
  ystar       = yhatsort_g + fitroberror$fv
  fitstar     = mhatr_h(fxd$x, xsort, ystar, h, c) 
  yhatsort_g2 = sapply(fxd$x, function(u) mhat_h(u, xsort, ystar, g))
  d[jj]       = max(abs(bandt*abs(fitstar - yhatsort_g2))) 
  print(jj)
  print(d[jj])
}


alpha         = 0.05
dstar         = quantile(d[d!=0], probs = 1-alpha)
dstar         = dstar*({bandt}^(-1))
yhatsort_h    = mhatr_h(fxd$x, xsort, ysort, h, c)

pdf(paste("LM_Neg", ".pdf", sep=""),width = 3, height = 3)
par(mar=c(3.0,3.1,1.5,0.7))
plot(xsort,
     ysort,
     pch = 20, cex = 0.5, col="#00000025",
     ylab = "LM Simulated Volatility",
     xlab = paste("LM Negative Proportion, h = ", round(h, 3), sep=""),
     cex.axis = 0.9, tck= -0.03, mgp=c(1.5,0.3,0), cex.lab = 0.95,
     main="Extremely High Attention",
     ylim = c(1.0002, 1.002371))


lines(fxd$x, yhatsort_h, col ="blue", lwd = 2, type = "l")
lines(fxd$x, yhatsort_h + dstar, col ="red", lwd = 2, type = "l", lty = "dashed")
lines(fxd$x, yhatsort_h - dstar, col ="red", lwd = 2, type = "l", lty = "dashed")
dev.off()

save.image("LM_negative")

upper_negy = yhatsort_h + dstar
lower_negy = yhatsort_h - dstar
negx       = fxd$x
save(upper_negy, file ="upper_negy")
save(lower_negy, file ="lower_negy")
save(negx, file = "lower_negx")
save(yhatsort_h, file="yhat_neg")
save(ysort, file="ysort_neg")
save(xsort, file="xsort_neg")
