options(stringsAsFactors = FALSE)
setwd("") # Set here WD
library(lubridate)
# Read in sentiment data
sentiment.df   = read.csv2("relevantdata_nd5_tl1.txt")
# Use only Days with Articles
sentiment.1.df = sentiment.df[sentiment.df$indicnews == 1, ]

# Change variables to numeric
sentiment.1.df$BL_neg_prop      = as.numeric(sentiment.1.df$BL_neg_prop)
sentiment.1.df$MPQA_neg_prop    = as.numeric(sentiment.1.df$MPQA_neg_prop)
sentiment.1.df$LM_neg_prop      = as.numeric(sentiment.1.df$LM_neg_prop)
sentiment.1.df$BL_pos_prop      = as.numeric(sentiment.1.df$BL_pos_prop)
sentiment.1.df$MPQA_pos_prop    = as.numeric(sentiment.1.df$MPQA_pos_prop)
sentiment.1.df$LM_pos_prop      = as.numeric(sentiment.1.df$LM_pos_prop)

# Change Date to Date Format
sentiment.1.df$date  = as.Date(sentiment.1.df$date, "%Y-%m-%d")
# Date with Year and Month
sentiment.1.df$date2 = format(sentiment.1.df$date, format="%Y-%m")

dates         = unique(as.character(sentiment.1.df$date2))

# Here: Leave out incomplete Months (Min Date and Max Date)
dates         = dates[!dates %in% c(min(dates), max(dates))]

###### PLOTS

# Plot for negative Sentiment

dates.mc      = 0
BL_MPQA.negc  = 0
LM_MPQA.negc  = 0
BL_LM.negc    = 0
comp.n        = 0
dates.date    = dates[1]

for(i in 1:length(dates)){
  sentiment.1.tmp.df = sentiment.1.df[sentiment.1.df$date2 == dates[i], ]
  BL_MPQA.negc[i]    = cor(sentiment.1.tmp.df$MPQA_neg_prop,
                           sentiment.1.tmp.df$BL_neg_prop)
  LM_MPQA.negc[i]    = cor(sentiment.1.tmp.df$LM_neg_prop,
                           sentiment.1.tmp.df$MPQA_neg_prop)
  BL_LM.negc[i]      = cor(sentiment.1.tmp.df$BL_neg_prop,
                           sentiment.1.tmp.df$LM_neg_prop)
  dates.date[i]      = dates[i]
}

# Plot for positive Sentiment

dates.mc      = 0
BL_MPQA.posc  = 0
LM_MPQA.posc  = 0
BL_LM.posc    = 0
comp.n        = 0
dates.date    = dates[1]

for(i in 1:length(dates)){
  sentiment.1.tmp.df = sentiment.1.df[sentiment.1.df$date2 == dates[i], ]
  BL_MPQA.posc[i]    = cor(sentiment.1.tmp.df$MPQA_pos_prop,
                           sentiment.1.tmp.df$BL_pos_prop)
  LM_MPQA.posc[i]    = cor(sentiment.1.tmp.df$LM_pos_prop,
                           sentiment.1.tmp.df$MPQA_pos_prop)
  BL_LM.posc[i]      = cor(sentiment.1.tmp.df$BL_pos_prop,
                           sentiment.1.tmp.df$LM_pos_prop)
  dates.date[i]      = dates[i]
}

limits = c(min(BL_MPQA.posc, LM_MPQA.posc, BL_LM.posc,
               BL_MPQA.negc, LM_MPQA.negc, BL_LM.negc),
           max(BL_MPQA.posc, LM_MPQA.posc, BL_LM.posc,
               BL_MPQA.negc, LM_MPQA.negc, BL_LM.negc))

pdf("fig_cor_sent_indices_neg.pdf",width=6.4,height=2.3)
par(mar=c(3.0,3.1,0.5,1.8))

plot(BL_MPQA.negc, type="l", ylim=limits,
     ylab="Correlation", xlab="Date", col="blue", lwd = 2,
     cex.axis = 0.9, tck=-0.03, mgp=c(1.5,0.3,0), cex.lab = 1, 
     xaxt = "n")

axis(1, at=c(1, 10, 20, 30, 40, 50, 59),
     labels=dates.date[c(1, 10, 20, 30, 40, 50, 59)],
     cex.axis = 0.9, tck=-0.03, mgp=c(1.5,0.3,0), cex.lab = 1)

lines(BL_LM.negc, col = "red", lwd = 2)
lines(LM_MPQA.negc, col = "darkgreen", lwd = 2)

dev.off()

pdf("fig_cor_sent_indices_pos.pdf",width=6.4,height=2.3)
par(mar=c(3.0,3.1,0.5,1.8))

plot( BL_MPQA.posc, type="l", ylim=limits ,xaxt="n",
      ylab="Correlation", xlab="Date", col="blue", lwd = 2,
      cex.axis = 0.9, tck=-0.03, mgp=c(1.5,0.3,0), cex.lab = 1)

axis(1, at=c(1, 10, 20, 30, 40, 50, 59),
     labels=dates.date[c(1, 10, 20, 30, 40, 50, 59)],
     cex.axis = 0.9, tck=-0.03, mgp=c(1.5,0.3,0), cex.lab = 1)

lines(BL_LM.posc, col = "red", lwd = 2)
lines(LM_MPQA.posc, col = "darkgreen", lwd = 2)

dev.off()