setwd("")
library(locfit)
library(KernSmooth)
sector_sim.df = read.csv2("EntirePanelSimulation.csv")
sector_sim.df = sector_sim.df[1:9]

par(mfrow=c(1,1))
pdf(paste("scat_", "EntirePanelSimulation_Three_methods",
          ".pdf", sep = ""),width = 5, height = 6.5)

par(mar=c(4.1,4.1,2.5,2.1))
par(mfrow=c(3,2))

x    = sector_sim.df$BL_Neg_Proportion
y    = sector_sim.df$BL_SimulatedVolatility
bw   = dpill(x, y)

plot(sector_sim.df$BL_Neg_Proportion,
     sector_sim.df$BL_SimulatedVolatility,
     pch = 20, cex = 0.5, col = "#00000025",
     ylab = "BL Simulated Volatility",
     xlab = paste("BL Negative Proportion, h = ", round(bw, 4), sep="") )


llr   = locfit(y~lp(x,h = bw,deg=1), kern ="gauss", deg = 1)
bands = scb(y~lp(x, h = bw, deg=1), type = 1, ev = lfgrid(20),
            simul = TRUE, kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")


bandstmp = bands

x    = sector_sim.df$BL_Pos_Proportion
bw   = dpill(x, y)

plot(sector_sim.df$BL_Pos_Proportion,
     sector_sim.df$BL_SimulatedVolatility,
     pch = 20, cex = 0.5, col = "#00000025",
     ylab = "BL Simulated Volatility",
     xlab = paste("BL Positive Proportion, h = ", round(bw, 4), sep = ""))

llr   = locfit(y~lp(x,h = bw,deg=1), kern ="gauss", deg = 1)
bands = scb(y~lp(x, h = bw, deg=1), type = 1, ev = lfgrid(20),
            simul = TRUE, kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")

#####

x    = sector_sim.df$LM_Neg_Proportion
y    = sector_sim.df$LM_SimulatedVolatility
bw = dpill(x, y)

plot(sector_sim.df$LM_Neg_Proportion,
     sector_sim.df$LM_SimulatedVolatility,
     pch = 20, cex = 0.5, col = "#00000025",
     ylab = "LM Simulated Volatility",
     xlab = paste("LM Negative Proportion, h = ", round(bw, 4), sep=""))

llr   = locfit(y ~ lp(x,h = bw, deg = 1), kern ="gauss", deg = 1)
bands = scb(y ~ lp(x, h = bw, deg = 1), type = 1, ev = lfgrid(20),
            simul = TRUE, kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")


x    = sector_sim.df$LM_Pos_Proportion
y    = sector_sim.df$LM_SimulatedVolatility
bw = dpill(x, y)
  1.06 * sd(x) * (length(x)^(-1/5))

plot(sector_sim.df$LM_Pos_Proportion,
     sector_sim.df$LM_SimulatedVolatility,
     pch = 20, cex = 0.5, col = "#00000025",
     ylab = "LM Simulated Volatility",
     xlab = paste("LM Positive Proportion, h = ", round(bw, 4), sep=""))


llr   = locfit(y~lp(x,h = bw,deg=1), kern ="gauss", deg = 1)
bands = scb(y~lp(x, h = bw,deg=1), type = 1, ev = lfgrid(20),
            simul = TRUE, kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")


x    = sector_sim.df$MPQA_Neg_Proportion
y    = sector_sim.df$MPQA_SimulatedVolatility
bw = dpill(x, y)


plot(sector_sim.df$MPQA_Neg_Proportion,
     sector_sim.df$MPQA_SimulatedVolatility,
     pch = 20, cex = 0.5, col="#00000025",
     ylab = "MPQA Simulated Volatility",
     xlab = paste("BL Negative Proportion, h=", round(bw, 4), sep=""))

llr   = locfit(y~lp(x,h = bw, deg = 1), kern ="gauss", deg = 1)
bands = scb(y~lp(x, h = bw, deg = 1), type = 1, ev = lfgrid(20), simul = TRUE,
            kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")

x    = sector_sim.df$MPQA_Pos_Proportion
y    = sector_sim.df$MPQA_SimulatedVolatility
bw = dpill(x, y)


plot(sector_sim.df$MPQA_Pos_Proportion,
     sector_sim.df$MPQA_SimulatedVolatility,
     pch = 20, cex = 0.5, col = "#00000025",
     ylab = "MPQA Simulated Volatility",
     xlab = paste("BL Positive Proportion, h = ", round(bw, 4), sep=""))


llr   = locfit(y~lp(x,h = bw,deg=1), kern ="gauss", deg = 1)
bands = scb(y~lp(x, h = bw,deg=1), type = 1, ev = lfgrid(20), simul = TRUE,
            kern = "gauss", deg = 1)

lines(llr, col = "blue", lwd = 2)
lines(bands$x, bands$lower, col="red", lwd=2, lty = "dashed")
lines(bands$x, bands$upper, col="red", lwd=2, lty = "dashed")

dev.off()
