setwd("")
options(stringsAsFactors = FALSE)

dir_raw = "raw_csv/"
dir_proc = "processed/single/"

l_rt      = function(x){diff(log(x), 1)}


# Constituents ------------------------------------------------------------

constituents = read.csv2("processed/constituents.csv")
# need all constituents from September 2009 on
cond         = (which(constituents$date == "10-09")+1) : dim(constituents)[1]
constituents = constituents[cond, ]

constituents = stack(constituents[, 2:dim(constituents)[2]])$values
constituents = unique(constituents)
constituents = constituents[constituents != ""]
constituents = constituents[!is.na(constituents)]
write.csv2(as.data.frame(constituents), "Constituents_small.csv", row.names= FALSE)
n=1

for(n in 1:32){

# Read in Files: Prices, High, Low, Open, Volume --------------------------


data_p      = read.csv2(paste(dir_raw, "RT_P", n, ".csv", sep="") )
data_p$date = as.Date(data_p$date, "%d.%m.%Y")

data_h      = read.csv2(paste(dir_raw, "RT_High", n, ".csv", sep="") )
data_h$date = as.Date(data_h$date, "%d.%m.%Y")

data_l      = read.csv2(paste(dir_raw, "RT_Low", n, ".csv", sep="") )
data_l$date = as.Date(data_l$date, "%d.%m.%Y")

data_o      = read.csv2(paste(dir_raw, "RT_Open", n, ".csv", sep="") )
data_o$date = as.Date(data_o$date, "%d.%m.%Y")

data_v      = read.csv2(paste(dir_raw, "RT_VO", n, ".csv", sep="") )
data_v$date = as.Date(data_v$date, "%d.%m.%Y")


# Use only needed Constituents --------------------------------------------
cond   = names(data_p) %in% c("date", paste("X", constituents, ".P.", sep ="") )
data_p = data_p[, cond]
data_h = data_h[, cond]
data_l = data_l[, cond]
data_o = data_o[, cond]
data_v = data_v[, cond]


# Variable Definition -----------------------------------------------------

m = dim(data_p)[2]


# Compute Log Returns -----------------------------------------------------

data_lr       = as.data.frame( sapply(data_p[2:m],  l_rt) )
data_lr$date  = data_p$date[-1]
data_lr       = data_lr[, c(m, 1:(m-1))] # Original order


# Compute Range Based Volatility ------------------------------------------

u = log(data_h[, 2:m])  - log(data_l[, 2:m]) # high  - low
d = log(data_l[, 2:m])  - log(data_o[, 2:m]) # low   - open
c = log(data_p[, 2:m])  - log(data_o[, 2:m]) # close - open

h_GK = 0.551 * ((u - d)^2) - ( 0.019*( (c*(u + d)) - (2*u*d)) ) - (0.383*(c^2))

h_GK$date  = data_p$date
h_GK       = h_GK[, c(m, 1:(m-1))] # Original order



# New Names for Dataframes ------------------------------------------------
nc        = nchar(names(data_p)[-1]) - 3
new_names = c("date", substr(names(data_p)[-1], 1, nc) )

names(data_h)    = new_names
names(data_l)    = new_names
names(data_lr)   = new_names
names(data_o)    = new_names
names(data_p)    = new_names
names(data_v)    = new_names
names(h_GK)      = new_names


# Save as CSV -------------------------------------------------------------

write.csv2(data_h , paste(dir_proc, "High_"        , n, ".csv", sep=""), row.names = FALSE)
write.csv2(data_l , paste(dir_proc, "Low_"         , n, ".csv", sep=""), row.names = FALSE)
write.csv2(data_lr, paste(dir_proc, "Log_Returns_" , n, ".csv", sep=""), row.names = FALSE)
write.csv2(data_o , paste(dir_proc, "Open_"        , n, ".csv", sep=""), row.names = FALSE)
write.csv2(data_p , paste(dir_proc, "Price_"       , n, ".csv", sep=""), row.names = FALSE)
write.csv2(data_v , paste(dir_proc, "Volume_"      , n, ".csv", sep=""), row.names = FALSE)
write.csv2(h_GK   , paste(dir_proc, "h_GK_"        , n, ".csv", sep=""), row.names = FALSE)

print(paste("n:", n))
}